@@ -4,7 +4,7 @@ from models import Strain
 
 class Weedmaps:
     def __init__(self):
-        self.search_url = constants.strains_search
+        self.search_url = constants.SEARCH_STRAINS
 
     def get_strain(self, query: str) -> Strain:
         if not query:
